/**
 * @brief 消息回调参数数据
 * @param {number}              [packet_type]       请求类型 参考NNIMPacketType
 * @param {number}              [cmd_type]          命令类型 参考NNIMCmdType
 * @param {string}              [belong_id]         当前语音房归属id，例如当前语音房归属哪个群id
 * @param {string}              [channel_id]        群id,如频道ID，群聊ID、直播间ID
 * @param {number}              [remote_user_id]    消息发送方uid
 * @param {string}              [msg]               消息内容
 * @param {number}              [msg_type]          消息类型 参考 NNIMMsgType
 * @param {string}              [session_id]        会话id
 * @param {string}              [msg_id]            消息id
 * @param {string}              [cmsg_id]           客户端消息id
 * @note
 */
interface NNIMMsgCallbackData {
    packet_type: number;
    cmd_type: number;
    belong_id: string;
    channel_id: string;
    remote_user_id: number;
    msg: string;
    msg_type: number;
    session_id: string;
    msg_id: string;
    cmsg_id: string;
}
/**
 * @brief 消息回调函数接口
 * @note
 */
interface NNIMMsgCallback {
    (data: NNIMMsgCallbackData): void;
}
/**
 * @brief 设置消息回调参数
 * @note
 */
interface NNImMsgCallbackParam {
    callback: NNIMMsgCallback;
}
/**
 * @brief 通知回调参数数据
 * @param {number}              [packet_type]       请求类型 参考NNIMPacketType
 * @param {number}              [cmd_type]          命令类型 参考NNIMCmdType
 * @param {string}              [belong_id]         当前语音房归属id，例如当前语音房归属哪个群id
 * @param {number}              [remote_user_id]    消息发送方uid
 * @param {string}              [msg]               通知内容
 * @param {string}              [title]             内容标题，推送离线时设备的一级标题
 * @param {number}              [msg_type]          消息类型 参考 NNIMMsgType
 * @param {number}              [notify_type]       通知类型 参考 NNIMNotifyType
 * @param {string}              [session_id]        会话id
 * @param {string}              [msg_id]            消息id
 * @param {string}              [cmsg_id]           客户端消息id
 * @note
 */
interface NNIMNotifyCallbackData {
    packet_type: number;
    cmd_type: number;
    belong_id: string;
    remote_user_id: number;
    msg: string;
    title: string;
    msg_type: number;
    notify_type: number;
    session_id: string;
    msg_id: string;
    cmsg_id: string;
}
/**
 * @brief 通知回调函数接口
 * @note
 */
interface NNIMNotifyCallback {
    (data: NNIMNotifyCallbackData): void;
}
/**
 * @brief 设置通知回调参数
 * @note
 */
interface NNImNotifyCallbackParam {
    callback: NNIMNotifyCallback;
}
/**
 * @brief 事件回调参数数据
 * @param {number}              [packet_type]       请求类型 参考NNIMPacketType
 * @param {number}              [cmd_type]          命令类型 参考NNIMCmdType
 * @param {string}              [device_id]         设备id
 * @param {number}              [status_code]       状态，参考NNIMErrCode
 * @param {number}              [event_type]        回执类型，参考NNIMNAckType
 * @param {string}              [session_id]        会话id
 * @param {string}              [msg_id]            消息id
 * @param {string}              [cmsg_id]           客户端消息id
 * @param {string}              [msg]               内容
 * @note
 */
interface NNIMEventCallbackData {
    packet_type: number;
    cmd_type: number;
    device_id: string;
    status_code: number;
    event_type: number;
    session_id: string;
    msg_id: string;
    cmsg_id: string;
    msg: string;
    business_type: number;
}
/**
 * @brief 事件回调函数接口
 * @note
 */
interface NNIMEventCallback {
    (data: NNIMEventCallbackData): void;
}
/**
 * @brief 设置事件回调参数
 * @note
 */
interface NNImEventCallbackParam {
    callback: NNIMEventCallback;
}
/**
 * @brief HTTP回调函数接口
 * @note
 */
interface NNIMHttpCallback {
    (json_body: string): void;
}
/**
 * @brief 设置HTTP回调参数
 * @note
 */
interface NNImHttpCallbackParam {
    callback: NNIMHttpCallback;
}
/**
 * @brief 初始化参数
 * @param {string}              [server_lsb_url]          im 服务器rul
 * @param {string}              [server_lsb_port]         im 服务器端口
 * @param {string}              [im_token]                im 登录token
 */
interface NNImInitParam {
    server_lsb_url: string;
    server_lsb_port: string;
    im_token: string;
}
/**
 * @brief 登录参数
 * @param {string}              [user_id]                   用户id
 * @param {string}              [laser_reg_id]              第三方极光注册ID，web端没有不传
 */
interface NNImLoginParam {
    user_id: string;
    laser_reg_id: string;
}

/**
 * @brief 群操作参数
 * @param {number}              [chat_type]                 聊天类型 参考 NNIMChatType
 * @param {string}              [belong_id]                 当前语音房归属id，例如当前语音房归属哪个群id
 * @param {string}              [channel_id]                群id,如频道ID，群聊ID、直播间ID
 * @param {string}              [msg]                       操作内容
 * @param {string}              [remote_group_chat_id]      群聊id/直播间id/派对房id，接收方
 * @param {number}              [message_type]              消息类型 参考 NNIMMsgType
 */
interface NNImGroupOptParam {
    chat_type: number;
    belong_id: string;
    channel_id: string;
    msg: string;
    remote_group_chat_id: string;
    message_type?: number;
}
/**
 * @brief 订阅参数
 * @param {string}              [subscribe_group_room_id]      订阅的群聊id/直播间id/派对房id
 * @param {string}              [subscribe_type]               订阅类型 参考NNIMCmdType中的ADD_SUBSCRIBER，REMOVE_SUBSCRIBER
 * @param {string}              [subscribe_uids]               订阅的用户id列表
 */
interface NNImSubscribeGroupParam {
    subscribe_group_room_id: string;
    subscribe_type: string;
    subscribe_uids: Array<string>;
}

/**
 * @brief 发送消息参数
 * @param {number}              [chat_type]                 聊天类型 参考 NNIMChatType
 * @param {number}              [message_type]              消息类型 参考 NNIMMsgType
 * @param {string}              [belong_id]                 当前语音房归属id，例如当前语音房归属哪个群id
 * @param {string}              [channel_id]                群id,如频道ID，群聊ID、直播间ID
 * @param {string}              [msg]                       操作内容
 * @param {string}              [remote_chat_id]            用户id/群聊id/直播间id/派对房id，消息接收方
 */
interface NNImSendMessageParam {
    chat_type: number;
    message_type: number;
    belong_id: string;
    channel_id: string;
    msg: string;
    remote_chat_id: string;
}
/**
 * @brief 消息操作参数
 * @param {string}              [msg_id]                    消息id
 * @param {string}              [cmsg_id]                   客户端消息id
 * @param {string}              [session_id]                会话id
 * @param {string}              [msg]                       操作内容
 * @param {number}              [business_type]             参考 NNIMCmdType 的消息操作
 */
interface NNImMessageOptParam {
    msg_id: string;
    cmsg_id: string;
    session_id: string;
    msg: string;
    business_type: number;
}
/**
 * @brief 获取历史消息参数
 * @param {number}              [count]                    消息数量
 * @param {number}              [sequence]                 消息的列表的序列
 * @param {string}              [session_id]               会话id
 */
interface NNImHistoryMsgListParam {
    count: number;
    sequence: number;
    session_id: string;
}

export { NNIMEventCallback, NNIMEventCallbackData, NNIMHttpCallback, NNIMMsgCallback, NNIMMsgCallbackData, NNIMNotifyCallback, NNIMNotifyCallbackData, NNImEventCallbackParam, NNImGroupOptParam, NNImHistoryMsgListParam, NNImHttpCallbackParam, NNImInitParam, NNImLoginParam, NNImMessageOptParam, NNImMsgCallbackParam, NNImNotifyCallbackParam, NNImSendMessageParam, NNImSubscribeGroupParam };
